@@ -1,16 +1,19 @@
 package Module::Install::Bundle;
 
-use Module::Install::Base;
-@ISA = qw(Module::Install::Base);
-
-$VERSION = '0.61';
-
 use strict;
+use Module::Install::Base;
 use Cwd ();
 use File::Find ();
 use File::Copy ();
 use File::Basename ();
 
+use vars qw{$VERSION $ISCORE @ISA};
+BEGIN {
+	$VERSION = '0.62';
+	$ISCORE  = 1;
+	@ISA     = qw{Module::Install::Base};
+}
+
 sub auto_bundle {
     my $self = shift;
 
