@@ -8,13 +8,13 @@ use Config ();
 use File::Spec ();
 use ExtUtils::MakeMaker ();
 
-use vars qw{$VERSION @ISA};
+use vars qw{$VERSION $ISCORE @ISA};
 BEGIN {
-	$VERSION = '0.61';
+	$VERSION = '0.62';
+	$ISCORE  = 1;
 	@ISA     = qw{Module::Install::Base};
 }
 
-
 # check if we can load some module
 ### Upgrade this to not have to load the module if possible
 sub can_use {
