@@ -13,7 +13,7 @@ use File::Spec ();
 
 use vars qw{$VERSION $ISCORE @ISA};
 BEGIN {
-	$VERSION = '0.66_02';
+	$VERSION = '0.62';
 	$ISCORE  = 1;
 	@ISA     = qw{Module::Install::Base};
 }
@@ -23,40 +23,10 @@ BEGIN {
 
 
 #####################################################################
-# CPAN Client
+# CPAN Clients
 
-# What CPAN client are we running under
-sub cpan {
-	return 'cpanpm'   if cpanpm();
-	return 'cpanplus' if cpanplus();
-	return 'legacy'   if cpanlegacy();
-}
-
-# Are we running a legacy client
-sub cpanlegacy {
-	return 1 if cpanpm_legacy();
-	return 1 if cpanplus_legacy();
-	return '';
-}
-
-# Are we currently running under a CPAN.pm client (modern method)
-# Returns the version of the CPAN.pm client.
+# Are we currently running under the CPAN.pm client
 sub cpanpm {
-	my $script = File::Spec->rel2abs($0);
-	return (
-		$ENV{PERL5_CPAN_IS_EXECUTING}
-		and
-		-f $script
-		and
-		$ENV{PERL5_CPAN_IS_EXECUTING} eq $script
-	)
-		? ($ENV{PERL5_CPAN_IS_VERSION} || -1)
-		: '';
-}
-
-# Are we currently running under the legacy CPAN client
-# This method is not reliable.
-sub cpanpm_legacy {
 	my $self = shift;
 
 	# Does the lock file exist?
@@ -99,14 +69,7 @@ sub cpanpm_config {
 
 # Are we currently running under the CPANPLUS client
 sub cpanplus {
-	my $script = File::Spec->rel2abs($0);
-	return (
-		$ENV{PERL5_CPANPLUS_IS_EXECUTING}
-		and
-		-f $script
-		and
-		$ENV{PERL5_CPANPLUS_IS_EXECUTING} eq $script
-	) ? ($ENV{PERL5_CPANPLUS_IS_VERSION} || -1) : '';
+	!! $ENV{PERL5_CPANPLUS_IS_RUNNING};
 }
 
 # Is CPANPLUS actually installed
@@ -114,9 +77,23 @@ sub cpanplus_available {
 	$_[0]->can_use('CPANPLUS');
 }
 
-# Are we (maybe) running under a legacy version of CPANPLUS
-sub cpanplus_legacy {
-	!! $ENV{CPANPLUS_IS_RUNNING};
+# Get a cpanplus configuration key.
+# Assumes you have already check cpanplus is at least installed.
+sub cpanplus_config {
+	my $self = shift;
+
+	# Load the CPANPLUS configuration
+	require CPANPLUS::Configure;
+	my $conf = CPANPLUS::Configure->new
+		or die "Failed to load CPANPLUS configuration";
+
+	# Get the configuration key
+	return $conf->get_conf(shift);
+}
+
+# Are we currently running under some automated testing system
+sub automated_testing {
+	!! $ENV{AUTOMATED_TESTING};
 }
 
 
@@ -151,25 +128,14 @@ sub no_mb {
 
 
 #####################################################################
-# Testing and Configuration Contexts
+# User vs Author Context
 
-# Are we in an interactive configuration environment
-sub interactive {
-	# Treat things interactively ONLY based on input
-	!! -t STDIN;
+sub user_mode {
+	1;
 }
 
-# Are we currently running under some sort of automated testing system
-sub automated_testing {
-	!! $ENV{AUTOMATED_TESTING};
-}
-
-sub user_context {
-	! $Module::Install::AUTHOR;
-}
-
-sub author_context {
-	!! $Module::Install::AUTHOR;
+sub author_mode {
+	1;
 }
 
 1;
